#!/common/math/9.0/Executables/MathKernel -script
(* The above line has to be at the start of the script  *)

(* Get command line input on number of kernels to use *)
nkernel= ToExpression[$CommandLine[[4;;]]];
Print[nkernel]

AppendTo[$Echo, "stdout"]
$NumberMarks=False

(* load cluster integration package to PBS Pro *)

Needs["ClusterIntegration`"]
(* ClusterIntegration`PBS`Private`DebugPrint := Print *)

(* Launch kernels onto cluster, passing in PBS command directives as needed *)
LaunchKernels[
 PBS["localhost", {"EnginePath" -> "/usr/pbs/", 
   "KernelProgram" -> "/common/math/math", "ToQueue" -> True, 
   "QueueName" -> "standard", 
   "BatchCommand" -> 
    "#!/bin/bash \n #PBS -N test \n #PBS -q standard \n #PBS -l \
walltime=00:10:00 \n #PBS -o \
/home/teh1m/math/gridmathematica/cse-030/test_out1 \n #PBS -j oe \
 \n #PBS -l select=1  \n `mathkernel`"}], nkernel ];

(* Code to estimate Pi using Monte Carlo Simulation in parallel *)
(*  Work is partitioned among available kernels  *)
Print /@ AbsoluteTiming[With[ {NUMPOINTS = 800000000, CPUS = Length[Kernels[]]},
  partitions = (Quotient[NUMPOINTS, CPUS] + 
     Join[Table[1, {Mod[NUMPOINTS, CPUS]}], 
      Table[0, {CPUS - Mod[NUMPOINTS, CPUS]}]]);
  N[Total@
      ParallelMap[# + 
         Total[Round[-Total[
              RandomReal[{-1/2, 1/2}, {#, 2}]^2, {2}] - .25]] &, 
       partitions]/NUMPOINTS*(1/(1/2)^2)]]]

 Print[ N[Pi,20] ]

 (*  Close kernels after computation *) 
CloseKernels[]
